/*
 * Copyright (c) 1997-2003 Erez Zadok
 * Copyright (c) 2001-2003 Stony Brook University
 * Copyright (c) 1997-2000 Columbia University
 *
 * For specific licensing information, see the COPYING file distributed with
 * this package, or get one from ftp://ftp.filesystems.org/pub/fist/COPYING.
 *
 * This Copyright notice must be kept intact and distributed with all
 * fistgen sources INCLUDING sources generated by fistgen.
 */
/*
 *  $Id: fist_ioctl.c,v 1.1 2003/02/09 23:54:03 cwright Exp $
 */

#ifdef HAVE_CONFIG_H
# include <config.h>
#endif /* HAVE_CONFIG_H */
#ifdef FISTGEN
# include "fist_rot13fs.h"
#endif /* FISTGEN */
#include "fist.h"
#include "rot13fs.h"

#include <sys/ioctl.h>
#include <fcntl.h>
#include <stdlib.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

static int opt_d = 0;
static int optcount;
static const char *progname;


void
usage(void)
{
  fprintf(stderr, "Usage: %s -d file [val]\n\tto set/get debugging values\n", progname);
  exit(1);
}


int
main(int argc, char *argv[])
{
  int fd, ret, val = 0;

  progname = argv[0];

  /* check that minimum number of args were specified */
  if (argc < 3)
    usage();

  if (strcmp(argv[1], "-d") == 0) {
    if (argc > 4)
      usage();
    opt_d++;
    optcount++;
  }

  /* check that at least one option was used */
  if (!optcount)
    usage();

  /* open file on which ioctl will operate */
  fd = open(argv[2], O_RDONLY);
  if (fd < 0) {
    perror(argv[2]);
    exit(1);
  }

  /* if specified 3rd arg, want to set debug level */
  if (opt_d) {
    if (argc == 4) {
      val = atoi(argv[3]);
      ret = ioctl(fd, FIST_IOCTL_SET_DEBUG_VALUE, &val);
      if (ret < 0) {
	perror("ioctl set");
	exit(1);
      }
    } else {
      ret = ioctl(fd, FIST_IOCTL_GET_DEBUG_VALUE, &val);
      if (ret < 0) {
	perror("ioctl get");
	exit(1);
      }
      printf("debug ioctl returned value %d\n", val);
    }
    goto out;
  }



 out:
  close(fd);
  exit(0);
}
